Print

Print


Commit in java/branches/hps-java_ecal-commissioning on MAIN
conditions/src/main/resources/HPS-ECalCommissioning/calibECal/default.gain+81172 -> 1173
conditions/src/main/resources/HPS-ECalCommissioning/daqmap/ecal.txt+9-81172 -> 1173
detector-data/detectors/HPS-ECalCommissioning/compact.xml+1-11172 -> 1173
ecal-recon/src/main/java/org/hps/recon/ecal/ECalUtils.java+20-101172 -> 1173
                                           /EcalRawConverter.java+6-11172 -> 1173
evio/src/main/java/org/hps/evio/ECalEvioReader.java+11-191172 -> 1173
                               /EventConstants.java+2-21172 -> 1173
monitoring-drivers/src/main/java/org/hps/monitoring/ecal/plots/EcalEventDisplay.java+67-561172 -> 1173
record-util/pom.xml+4-21172 -> 1173
record-util/src/main/java/org/hps/record/et/EtConnection.java+5-51172 -> 1173
steering-files/src/main/resources/org/hps/steering/monitoring/ECalLedCommissioning.lcsim+3-21172 -> 1173
                                                             /EcalMonitoringFinal.lcsim+2-11172 -> 1173
+138-107
12 modified files
commit today changes, on the branch

java/branches/hps-java_ecal-commissioning/conditions/src/main/resources/HPS-ECalCommissioning/calibECal
default.gain 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/conditions/src/main/resources/HPS-ECalCommissioning/calibECal/default.gain	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/conditions/src/main/resources/HPS-ECalCommissioning/calibECal/default.gain	2014-10-11 17:33:20 UTC (rev 1173)
@@ -441,3 +441,11 @@
 23	-3	1.0
 23	-4	1.0
 23	-5	1.0
+
+#A.C. DO NOT TOUCH THESE
+-7      -1    	1.0
+-6	-1	1.0
+-5	-1	1.0
+-7	1	1.0
+-6	1	1.0
+-5	1	1.0
\ No newline at end of file

java/branches/hps-java_ecal-commissioning/conditions/src/main/resources/HPS-ECalCommissioning/daqmap
ecal.txt 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/conditions/src/main/resources/HPS-ECalCommissioning/daqmap/ecal.txt	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/conditions/src/main/resources/HPS-ECalCommissioning/daqmap/ecal.txt	2014-10-11 17:33:20 UTC (rev 1173)
@@ -441,12 +441,13 @@
 -23 -3 39 20 10
 -23 -4 39 20 11
 -23 -5 39 20 12
-
-
 #A. Celentano the 3 missing slots that (may) have data
-0 1 37 20 13
-0 2 37 20 14
-0 3 37 20 15
-0 -1 39 20 13
-0 -2 39 20 14
-0 -3 39 20 15
\ No newline at end of file
+#Associate them with missing crystals in the hole
+#TOP
+-7 1 37 20 13
+-6 1 37 20 14
+-5 1 37 20 15
+#BOTTOM
+-7 -1 39 20 13
+-6 -1 39 20 14
+-5 -1 39 20 15

java/branches/hps-java_ecal-commissioning/detector-data/detectors/HPS-ECalCommissioning
compact.xml 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/detector-data/detectors/HPS-ECalCommissioning/compact.xml	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/detector-data/detectors/HPS-ECalCommissioning/compact.xml	2014-10-11 17:33:20 UTC (rev 1173)
@@ -315,7 +315,7 @@
             <material name="LeadTungstate" />
             <dimensions x1="ecal_front" y1="ecal_front" x2="ecal_back" y2="ecal_back" z="ecal_z" />          
             <layout beamgap="20.0*mm" nx="46" ny="5" dface="ecal_dface">
-                <remove ixmin="-10" ixmax="-2" iymin="-1" iymax="1" />
+                <remove ixmin="-10" ixmax="-2" iymin="-1" iymax="1" /> 
                 <top dx="ecal_dface*tan(beam_angle)" dy="0." dz="0."/>
                 <bottom dx="ecal_dface*tan(beam_angle)" dy="0." dz="0."/>
             </layout>

java/branches/hps-java_ecal-commissioning/ecal-recon/src/main/java/org/hps/recon/ecal
ECalUtils.java 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/ecal-recon/src/main/java/org/hps/recon/ecal/ECalUtils.java	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/ecal-recon/src/main/java/org/hps/recon/ecal/ECalUtils.java	2014-10-11 17:33:20 UTC (rev 1173)
@@ -1,7 +1,7 @@
 package org.hps.recon.ecal;
 
 import org.lcsim.event.CalorimeterHit;
-
+import java.lang.Math;
 /**
  *
  * @author Sho Uemura <[log in to unmask]>
@@ -101,30 +101,40 @@
     }
     
   
+   
      /**
      * This is a very basic method that, given an array with the raw-waveform (in FADC units), returns the amplitude (in mV)
      * @param data Array with data from FADC, in fadc units
      * @param lenght The array lenght
      * @param pedestalSamples How many samples at the beginning of the array to use for the pedestal. Must be < lenght
-     * @return
+     * @return double[], 0 is the amplitude in mV, 1 is the offest in ADC counts, 2 is the RMS in adc counts
      */
-    public static double computeAmplitude(short [] data, int lenght, int pedestalSamples){
-    	double amplitude,pedestal;
+    public static double[] computeAmplitude(short [] data, int lenght, int pedestalSamples){
+    	double amplitude,pedestal,noise;
     	pedestal=0;
+    	noise=0;
     	amplitude=data[0];
+    	double[] ret={0.,0.,0.};
     	if (pedestalSamples>lenght){
-    		return 0;
+    		return ret;
     	}
     	for (int jj = 0; jj < lenght; jj++){
-    		if (jj<pedestalSamples) pedestal+=data[jj];
+    		if (jj<pedestalSamples){
+    			pedestal+=data[jj];
+    			noise+=data[jj]*data[jj];
+    		}
     		if (data[jj]>amplitude) amplitude=data[jj];
     	}
     	pedestal/=pedestalSamples;
+    	noise/=pedestalSamples;
+    	noise=Math.sqrt(noise-pedestal*pedestal);
     	amplitude-=pedestal;
+    
+    	amplitude*=adcResolution*1000;
+    	ret[0]=amplitude;
+    	ret[1]=pedestal;
+    	ret[2]=noise;
+    	return ret;
     	
-    	amplitude*=adcResolution;
-    	
-    	return amplitude;
-    	
     }
 }

java/branches/hps-java_ecal-commissioning/ecal-recon/src/main/java/org/hps/recon/ecal
EcalRawConverter.java 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverter.java	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/ecal-recon/src/main/java/org/hps/recon/ecal/EcalRawConverter.java	2014-10-11 17:33:20 UTC (rev 1173)
@@ -30,13 +30,18 @@
         this.use2014Gain = use2014Gain;
     }
 
+    /**
+     * @TODO: fix the pedestal
+     * @param hit
+     * @return
+     */
     private short sumADC(RawTrackerHit hit) {
         //Sum all pedestal subtracted ADC values 
         //return scale * (amplitude + 0.5) + pedestal;
         if (debug) {
             System.out.println("Summing ADC for hit: " + hit.toString());
         }
-       // double pedestal = EcalConditions.physicalToPedestal(hit.getCellID()); A.C. for now
+       // double pedestal = EcalConditions.physicalToPedestal(hit.getCellID());
         double pedestal = 0;
         short sum = 0;
         short samples[] = hit.getADCValues();

java/branches/hps-java_ecal-commissioning/evio/src/main/java/org/hps/evio
ECalEvioReader.java 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/evio/src/main/java/org/hps/evio/ECalEvioReader.java	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/evio/src/main/java/org/hps/evio/ECalEvioReader.java	2014-10-11 17:33:20 UTC (rev 1173)
@@ -65,14 +65,10 @@
                             }
                             
 			    else if ((tag==EventConstants.ECAL_WINDOW_BANK_TAG)||(tag== EventConstants.ECAL_PULSE_BANK_TAG)||(tag==EventConstants.ECAL_PULSE_INTEGRAL_BANK_TAG)){
-                            
-                          
-                            
+                                                                            
                                 for (CompositeData cdata : slotBank.getCompositeData()) {
                                 
-				    if (cdata==null){
-				      System.out.println("Cazzo.! "+slotBank.getHeader().getTag());
-				    }
+				   
                                     if (slotBank.getHeader().getTag() != bankTag) {
                                         bankTag = slotBank.getHeader().getTag();
                                         System.out.printf("ECal format tag: 0x%x\n", bankTag);
@@ -156,9 +152,9 @@
                 if (id == null) {
                     System.out.printf("Crate %d, slot %d, channel %d not found in map\n", crate, slot, channel);
                 }
-                else if ((slot==20)&&(channel>=13)) { //A.C. temporary work around. Has to be here since we need to read the full EVIO composite.
-		  continue;
-		}
+                else if ((slot==20)&&(channel>=13)){
+                	continue;	
+                }
                 else {
                     hits.add(new BaseRawTrackerHit(0, id, adcValues, new ArrayList<SimTrackerHit>(), EcalConditions.getSubdetector().getDetectorElement().findDetectorElement(new Identifier(id)).get(0)));
                 }
@@ -206,9 +202,9 @@
                         System.out.printf("Crate %d, slot %d, channel %d not found in map\n", crate, slot, channel);
                     } 
                     else if ((slot==20)&&(channel>=13)) { //A.C. temporary work around. Has to be here since we need to read the full EVIO composite.
-		      continue;
-		    }
-		    else {
+                    	continue;
+                    }
+                    else {
                         hits.add(new BaseRawTrackerHit(pulseNum, id, adcValues, new ArrayList<SimTrackerHit>(), EcalConditions.getSubdetector().getDetectorElement().findDetectorElement(new Identifier(id)).get(0)));
                     }
                 }
@@ -238,9 +234,7 @@
                 System.out.println("slot#=" + slot + "; trigger=" + trigger + "; timestamp=" + timestamp + "; nchannels=" + nchannels);
             }
             for (int j = 0; j < nchannels; j++) {
-                short channel = cdata.getByte();
-                //A.C. temporary work-around
-                if ((slot==20)&&(channel>=13)) continue;
+                short channel = cdata.getByte();                
                 int npulses = cdata.getNValue();
                 if (debug) {
                     System.out.println("  channel=" + channel + "; npulses=" + npulses);
@@ -255,10 +249,8 @@
                     }
                     if (id == null) {
                         System.out.printf("Crate %d, slot %d, channel %d not found in map\n", crate, slot, channel);
-                    } 
-                    else if ((slot==20)&&(channel>=13)) { //A.C. temporary work around. Has to be here since we need to read the full EVIO composite.
-		      continue;
-		    }
+                    }
+                    else if ((slot==20)&&(channel>=13)) continue;
                     else {
                         hits.add(new BaseRawCalorimeterHit(id, pulseIntegral, pulseTime));
                     }

java/branches/hps-java_ecal-commissioning/evio/src/main/java/org/hps/evio
EventConstants.java 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/evio/src/main/java/org/hps/evio/EventConstants.java	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/evio/src/main/java/org/hps/evio/EventConstants.java	2014-10-11 17:33:20 UTC (rev 1173)
@@ -15,8 +15,8 @@
     public static final int EVENTID_BANK_TAG = 0xC000;
     public static final int EVENT_BANK_NUM = 0xCC;
     // These correspond to ROC (readout crate) IDs from the DAQ.
-    public static final int ECAL_TOP_BANK_TAG = 0x1;
-    public static final int ECAL_BOTTOM_BANK_TAG = 0x2;
+    public static final int ECAL_TOP_BANK_TAG = 0x25;
+    public static final int ECAL_BOTTOM_BANK_TAG = 0x27;
     public static final int SVT_BANK_TAG = 0x3;
     // These values are put into the number field of the banks.
     // FIXME Bank numbers should actually be sequentially numbered and not hard-coded.

java/branches/hps-java_ecal-commissioning/monitoring-drivers/src/main/java/org/hps/monitoring/ecal/plots
EcalEventDisplay.java 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/record-util/pom.xml	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/record-util/pom.xml	2014-10-11 17:33:20 UTC (rev 1173)
@@ -33,9 +33,11 @@
             <artifactId>hps-evio</artifactId>
         </dependency>
         <dependency>
-            <groupId>org.jlab.coda</groupId>
+	  
+            <groupId>org.jlab.coda</groupId> 
             <artifactId>et</artifactId>
-            <version>14.1</version>
+            <version>12.0</version>
+
         </dependency>
     </dependencies>
 </project>

java/branches/hps-java_ecal-commissioning/record-util/src/main/java/org/hps/record/et
EtConnection.java 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/record-util/src/main/java/org/hps/record/et/EtConnection.java	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/record-util/src/main/java/org/hps/record/et/EtConnection.java	2014-10-11 17:33:20 UTC (rev 1173)
@@ -12,7 +12,7 @@
 import org.jlab.coda.et.enums.Mode;
 import org.jlab.coda.et.enums.Modify;
 import org.jlab.coda.et.exception.EtBusyException;
-import org.jlab.coda.et.exception.EtClosedException;
+//import org.jlab.coda.et.exception.EtClosedException;
 import org.jlab.coda.et.exception.EtDeadException;
 import org.jlab.coda.et.exception.EtEmptyException;
 import org.jlab.coda.et.exception.EtException;
@@ -118,7 +118,8 @@
     EtEvent[] readEtEvents() 
             throws IOException, EtException, EtDeadException, 
             EtEmptyException, EtBusyException, EtTimeoutException, 
-            EtWakeUpException, EtClosedException {
+  //          EtClosedException,
+            EtWakeUpException {
         return getEtSystem().getEvents(
             getEtAttachment(),
             waitMode,
@@ -126,7 +127,6 @@
             waitTime,
             chunkSize);        
     }     
-    
     /**
      * Create an EtConnection with full list of configuration parameters.
      * @param name The name of the ET system e.g. the buffer file on disk.
@@ -207,8 +207,8 @@
         } catch (IOException | 
                 EtException | 
                 EtExistsException | 
-                EtClosedException | 
-                EtDeadException | 
+  //              EtClosedException | 
+  //              EtDeadException | 
                 EtTooManyException e) {
             throw new RuntimeException("Failed to create ET connection.", e);
         }

java/branches/hps-java_ecal-commissioning/steering-files/src/main/resources/org/hps/steering/monitoring
ECalLedCommissioning.lcsim 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/steering-files/src/main/resources/org/hps/steering/monitoring/ECalLedCommissioning.lcsim	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/steering-files/src/main/resources/org/hps/steering/monitoring/ECalLedCommissioning.lcsim	2014-10-11 17:33:20 UTC (rev 1173)
@@ -11,7 +11,7 @@
   <!--      <driver name="ConditionsDriver"/> -->
         <driver name="CalibrationDriver"/>
         <driver name="EcalRawConverter"/>     
-        <driver name="EcalLedCommissioning"/>         <!-- Ecal event display -->
+        <driver name="EcalEventDisplay"/>         <!-- Ecal event display -->
 
 
 <!--        <driver name="RunControlDriver" />-->
@@ -35,10 +35,11 @@
         </driver>
         
        
-        <driver name="EcalLedCommissioning" type="org.hps.monitoring.ecal.plots.EcalLedCommissioning">
+        <driver name="EcalEventDisplay" type="org.hps.monitoring.ecal.plots.EcalEventDisplay">
             <inputCollection>EcalCalHits</inputCollection>
             <inputCollectionRaw>EcalReadoutHits</inputCollectionRaw>
             <inputClusterCollection>EcalClusters</inputClusterCollection>
+            <enableAllFadc>true</enableAllFadc>
             <pedSamples>20</pedSamples>
             <maxEch>2.0</maxEch>
             <eventRefreshRate>100</eventRefreshRate>

java/branches/hps-java_ecal-commissioning/steering-files/src/main/resources/org/hps/steering/monitoring
EcalMonitoringFinal.lcsim 1172 -> 1173
--- java/branches/hps-java_ecal-commissioning/steering-files/src/main/resources/org/hps/steering/monitoring/EcalMonitoringFinal.lcsim	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/steering-files/src/main/resources/org/hps/steering/monitoring/EcalMonitoringFinal.lcsim	2014-10-11 17:33:20 UTC (rev 1173)
@@ -75,10 +75,11 @@
         <inputCollection>EcalCalHits</inputCollection>
         </driver>
        
-        <driver name="EcalEventDisplay" type="org.hps.monitoring.ecal.plots.EcalEventDisplay">
+        <driver name="EcalEventDisplay" type="org.hps.monitoring.ecal.plots.EcalEventDisplay"> 
             <inputCollection>EcalCalHits</inputCollection>
             <inputCollectionRaw>EcalReadoutHits</inputCollectionRaw>
             <inputClusterCollection>EcalClusters</inputClusterCollection>
+            <pedSamples>20</pedSamples>
             <maxEch>2.0</maxEch>
             <eventRefreshRate>100</eventRefreshRate>
         </driver>
SVNspam 0.1
--- java/branches/hps-java_ecal-commissioning/monitoring-drivers/src/main/java/org/hps/monitoring/ecal/plots/EcalEventDisplay.java	2014-10-11 16:16:23 UTC (rev 1172)
+++ java/branches/hps-java_ecal-commissioning/monitoring-drivers/src/main/java/org/hps/monitoring/ecal/plots/EcalEventDisplay.java	2014-10-11 17:33:20 UTC (rev 1173)
@@ -29,7 +29,7 @@
 import org.lcsim.util.aida.AIDA;
 
 /**
  *  The driver <code>EcalLEDCommissioning</code> implements the histogram shown to the user 
  * in the fifth tab of the Monitoring Application, when using the Ecal monitoring lcsim file.
  * IT ALSO OPENS KYLE's EVENT DISPLAY <code>PEventViewer</code>.
  * The implementation is as follows:
@@ -42,7 +42,7 @@
  *  *
  */
 
-public class EcalLedCommissioning extends Driver implements CrystalListener, ActionListener {
+public class EcalEventDisplay extends Driver implements CrystalListener, ActionListener {
 
   
     String inputCollection = "EcalCalHits";
@@ -62,7 +62,17 @@
     int[] windowRaw=new int[47*11];//in case we have the raw waveform, this is the window lenght (in samples)
 	boolean[] isFirstRaw=new boolean[47*11];
 	
-    private PEventViewer viewer; //this is the Kyle event viewer.    
+	/*this is the flag that checks if the event display enables to look at FADC 20, ch 13,14,15.
+	These are FADC channels not connected to any crystal. But,
+	-For ECAL TOP:
+		 at ch 13 cosmic counter 1,
+		 at ch 14 comsic counter 2,
+		 at ch 14 led
+	-For ECAL BOTTOM:
+		nothing at the moment*/
+	boolean enableAllFadc=false; 
+    
+	private PEventViewer viewer; //this is the Kyle event viewer.    
 
     
     ArrayList<IHistogram1D> channelEnergyPlot;
@@ -76,10 +86,14 @@
     
     double maxEch = 2500 * ECalUtils.MeV;
     
-    public EcalLedCommissioning() {
+    public EcalEventDisplay() {
     	
     }
 
+    public void setEnableAllFadc(boolean enableAllFadc){
+        this.enableAllFadc = enableAllFadc;
+    }
+    
     public void setMaxEch(double maxEch) {
         this.maxEch = maxEch;
     }
@@ -119,7 +133,6 @@
        //channelRawWaveform=new ArrayList<ICloud1D>();
        channelTimeVsEnergyPlot=new ArrayList<IHistogram2D>();
        //create the histograms for single channel energy and time distribution.
-       //these are NOT shown in this plotter, but are used in the event display.
        for(int ii = 0; ii < (47*11); ii = ii +1){
              int row=ECalUtils.getRowFromHistoID(ii);
              int column=ECalUtils.getColumnFromHistoID(ii);      
@@ -246,21 +259,24 @@
         	for (RawTrackerHit hit : hits) {
         		 row=hit.getIdentifierFieldValue("iy");
                  column=hit.getIdentifierFieldValue("ix");
-                 if ((row!=0)&&(column!=0)&&(!ECalUtils.isInHole(row,column))){
-                     ii = ECalUtils.getHistoIDFromRowColumn(row,column);
-                     if (isFirstRaw[ii]){ //at the very first hit we read for this channel, we need to read the window length and save it
-                    	 isFirstRaw[ii]=false;
-                    	 windowRaw[ii]=hit.getADCValues().length;                   	 
-                    	 channelRawWaveform.set(ii,aida.histogram1D(detector.getDetectorName() + " : " + inputCollectionRaw + " : Raw Waveform : " + (column) + " "+ (row)+ ": "+ii,windowRaw[ii],-0.5*ECalUtils.ecalReadoutPeriod,(-0.5+windowRaw[ii])*ECalUtils.ecalReadoutPeriod));
-                     }
-                     if (do_update){
-                         channelRawWaveform.get(ii).reset();                     
-                         for (int jj = 0; jj < windowRaw[ii]; jj++) {
-                             channelRawWaveform.get(ii).fill(jj*ECalUtils.ecalReadoutPeriod, hit.getADCValues()[jj]*ECalUtils.adcResolution*1000);
-                         }                  
-                         result=ECalUtils.computeAmplitude(hit.getADCValues(),windowRaw[ii],pedSamples);
-                         channelRawWaveform.get(ii).setTitle("Ampl: "+String.format("%.2f",result[0])+" mV , ped : "+String.format("%.2f",result[1])+" "+String.format("%.2f",result[2])+" ADC counts");
-                     } 
+                 if ((row!=0)&&(column!=0)){
+                	 if (!ECalUtils.isInHole(row,column)||(enableAllFadc)){
+                	 
+                		 ii = ECalUtils.getHistoIDFromRowColumn(row,column);
+                		 if (isFirstRaw[ii]){ //at the very first hit we read for this channel, we need to read the window length and save it
+                			 isFirstRaw[ii]=false;
+                			 windowRaw[ii]=hit.getADCValues().length;                   	 
+                			 channelRawWaveform.set(ii,aida.histogram1D(detector.getDetectorName() + " : " + inputCollectionRaw + " : Raw Waveform : " + (column) + " "+ (row)+ ": "+ii,windowRaw[ii],-0.5*ECalUtils.ecalReadoutPeriod,(-0.5+windowRaw[ii])*ECalUtils.ecalReadoutPeriod));
+                		 }
+                		 if (do_update){
+                			 channelRawWaveform.get(ii).reset();                     
+                			 for (int jj = 0; jj < windowRaw[ii]; jj++) {
+                				 channelRawWaveform.get(ii).fill(jj*ECalUtils.ecalReadoutPeriod, hit.getADCValues()[jj]*ECalUtils.adcResolution*1000);
+                			 }                  
+                			 result=ECalUtils.computeAmplitude(hit.getADCValues(),windowRaw[ii],pedSamples);
+                			 channelRawWaveform.get(ii).setTitle("Ampl: "+String.format("%.2f",result[0])+" mV , ped : "+String.format("%.2f",result[1])+" "+String.format("%.2f",result[2])+" ADC counts");
+                		 } 
+                	 }
                  }
             }
         }
@@ -319,52 +335,47 @@
     	itmpx=(int) ecalPoint.getX(); //column
     	itmpy=(int) ecalPoint.getY(); //row
     	
-    	if ((itmpx!=0)&&(itmpy!=0)&&(!ECalUtils.isInHole(itmpy,itmpx))){
-    		ix=itmpx;
-    		iy=itmpy;
-    	    id=ECalUtils.getHistoIDFromRowColumn(iy,ix);
-    	    System.out.println("Crystal event: "+ix+" "+iy+" "+id);
+    	if ((itmpx!=0)&&(itmpy!=0))
+    		if (!ECalUtils.isInHole(itmpy,itmpx)||(enableAllFadc)){
+    			ix=itmpx;
+    			iy=itmpy;
+    			id=ECalUtils.getHistoIDFromRowColumn(iy,ix);
+    			System.out.println("Crystal event: "+ix+" "+iy+" "+id);
         
     	    
     	    
     	    
     	    
-        	plotter.region(0).clear();
-            pstyle.xAxisStyle().setLabel("Hit energy (GeV)");
-            pstyle.yAxisStyle().setLabel("");
-            plotter.region(0).plot(channelEnergyPlot.get(id),pstyle);
+    			plotter.region(0).clear();
+    			pstyle.xAxisStyle().setLabel("Hit energy (GeV)");
+    			pstyle.yAxisStyle().setLabel("");
+    			plotter.region(0).plot(channelEnergyPlot.get(id),pstyle);
        
-        	plotter.region(1).clear();
-            pstyle.xAxisStyle().setLabel("Hit Time (ns)");
-            pstyle.yAxisStyle().setLabel("");    
-            plotter.region(1).plot(channelTimePlot.get(id),pstyle);           	    
+    			plotter.region(1).clear();
+    			pstyle.xAxisStyle().setLabel("Hit Time (ns)");
+    			pstyle.yAxisStyle().setLabel("");    
+    			plotter.region(1).plot(channelTimePlot.get(id),pstyle);           	    
      
-            plotter.region(2).clear();
-            pstyle.xAxisStyle().setLabel("Hit Time (ns)");
-            pstyle.yAxisStyle().setLabel("Hit Energy (GeV)");    
-        	plotter.region(2).plot(channelTimeVsEnergyPlot.get(id),pstyle);
+    			plotter.region(2).clear();
+    			pstyle.xAxisStyle().setLabel("Hit Time (ns)");
+    			pstyle.yAxisStyle().setLabel("Hit Energy (GeV)");    
+    			plotter.region(2).plot(channelTimeVsEnergyPlot.get(id),pstyle);
 
-        	plotter.region(3).clear();
+    			plotter.region(3).clear();
         	
         	 
-    	    if (!isFirstRaw[id]){
-    	        pstyle.yAxisStyle().setLabel("Signal amplitude (mV)");
-    	        pstyle.xAxisStyle().setLabel("Time (ns)");
-    	        pstyle.dataStyle().fillStyle().setColor("orange");
-    	        pstyle.dataStyle().markerStyle().setColor("orange");
-    	        pstyle.dataStyle().errorBarStyle().setVisible(false);
-    	    }
-    	    else{
-    	    	pstyle.xAxisStyle().setLabel("Hit Energy (GeV)");    
-                pstyle.yAxisStyle().setLabel("");  	    
-    	    }
-    	    plotter.region(3).plot(channelRawWaveform.get(id),pstyle);
-        
-
-    	    
- 
-         
-       
+    			if (!isFirstRaw[id]){
+    				pstyle.yAxisStyle().setLabel("Signal amplitude (mV)");
+    				pstyle.xAxisStyle().setLabel("Time (ns)");
+    				pstyle.dataStyle().fillStyle().setColor("orange");
+    				pstyle.dataStyle().markerStyle().setColor("orange");
+    				pstyle.dataStyle().errorBarStyle().setVisible(false);
+    			}
+    			else{
+    				pstyle.xAxisStyle().setLabel("Hit Energy (GeV)");    
+    				pstyle.yAxisStyle().setLabel("");  	    
+    			}
+    			plotter.region(3).plot(channelRawWaveform.get(id),pstyle);       
     	}
     }    
     
@@ -29,7 +29,7 @@
 
 /**
- *  The driver <code>EcalLEDCommissioning</code> implements the histogram shown to the user 
+ *  The driver <code>EcalEventDisplay</code> implements the histogram shown to the user 
  * in the fifth tab of the Monitoring Application, when using the Ecal monitoring lcsim file.
  * IT ALSO OPENS KYLE's EVENT DISPLAY <code>PEventViewer</code>.

java/branches/hps-java_ecal-commissioning/record-util
pom.xml 1172 -> 1173